#ifndef BISON_CONFIG_PARSE_H
# define BISON_CONFIG_PARSE_H

#ifndef YYSTYPE
typedef union {
    int         num;
    bool        b;
    char       *s;

    path_list  *pathlist;
    user_list  *userlist;
    port_list  *portlist;

    config_t   *config;
} yystype;
# define YYSTYPE yystype
# define YYSTYPE_IS_TRIVIAL 1
#endif
# define	NUM	257
# define	BOOLEAN	258
# define	ID	259
# define	PATH	260
# define	K_BIND	261
# define	K_OPEN_RO	262
# define	K_OPEN_RW	263
# define	K_OPEN_AO	264
# define	K_UNLINK	265
# define	K_AUTH	266
# define	K_RUNAS	267
# define	K_FORK	268
# define	K_UNPRIV_USER	269
# define	K_CHROOT	270
# define	K_ALLOW_RERUN	271


extern YYSTYPE yylval;

#endif /* not BISON_CONFIG_PARSE_H */
